==> estateplat-common-1.2.4-20201124.004642-542-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxMzHydj.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/11
 * @description 省级信息共享-民政-婚姻信息
 */
@Table(name = "xxgx_mz_dmxx")
public class XxgxMzHydj {
    @Id
    private String hydjid;//婚姻登记id
    private String sfzh;//身份证号
    private String xm;//姓名
    private Date mcsrq;//男出生日期
    private Date wcsrq;//女出生日期
    private String zzh;//结婚证/离婚证字号
    private String msfzjh;//男身份证号
    private String wsfzjh;//女身份证号
    private String djjgdm;//登记机关代码
    private String djjgmc;//登记机关名称
    private String mxm;//男姓名
    private String wxm;//女姓名
    private String mgj;//男国籍
    private String wgj;//女国籍
    private Date djrq;//登记日期
    private String hydjywlx;//婚姻登记业务类型
    private String proid;//项目id
    private String qlrid;//权利人id

    public String getHydjid() {
        return hydjid;
    }

    public void setHydjid(String hydjid) {
        this.hydjid = hydjid;
    }

    public String getSfzh() {
        return sfzh;
    }

    public void setSfzh(String sfzh) {
        this.sfzh = sfzh;
    }

    public String getXm() {
        return xm;
    }

    public void setXm(String xm) {
        this.xm = xm;
    }

    public Date getMcsrq() {
        return mcsrq;
    }

    public void setMcsrq(Date mcsrq) {
        this.mcsrq = mcsrq;
    }

    public Date getWcsrq() {
        return wcsrq;
    }

    public void setWcsrq(Date wcsrq) {
        this.wcsrq = wcsrq;
    }

    public String getZzh() {
        return zzh;
    }

    public void setZzh(String zzh) {
        this.zzh = zzh;
    }

    public String getMsfzjh() {
        return msfzjh;
    }

    public void setMsfzjh(String msfzjh) {
        this.msfzjh = msfzjh;
    }

    public String getWsfzjh() {
        return wsfzjh;
    }

    public void setWsfzjh(String wsfzjh) {
        this.wsfzjh = wsfzjh;
    }

    public String getDjjgdm() {
        return djjgdm;
    }

    public void setDjjgdm(String djjgdm) {
        this.djjgdm = djjgdm;
    }

    public String getDjjgmc() {
        return djjgmc;
    }

    public void setDjjgmc(String djjgmc) {
        this.djjgmc = djjgmc;
    }

    public String getMxm() {
        return mxm;
    }

    public void setMxm(String mxm) {
        this.mxm = mxm;
    }

    public String getWxm() {
        return wxm;
    }

    public void setWxm(String wxm) {
        this.wxm = wxm;
    }

    public String getMgj() {
        return mgj;
    }

    public void setMgj(String mgj) {
        this.mgj = mgj;
    }

    public String getWgj() {
        return wgj;
    }

    public void setWgj(String wgj) {
        this.wgj = wgj;
    }

    public Date getDjrq() {
        return djrq;
    }

    public void setDjrq(Date djrq) {
        this.djrq = djrq;
    }

    public String getHydjywlx() {
        return hydjywlx;
    }

    public void setHydjywlx(String hydjywlx) {
        this.hydjywlx = hydjywlx;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }
}

==> estateplat-common-1.2.4-20210622.094623-796-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxMzHydj.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/11
 * @description 省级信息共享-民政-婚姻信息
 */
@Table(name = "xxgx_mz_hydj")
public class XxgxMzHydj {
    @Id
    private String hydjid;//婚姻登记id
    private String sfzh;//身份证号
    private String xm;//姓名
    private Date mcsrq;//男出生日期
    private Date wcsrq;//女出生日期
    private String zzh;//结婚证/离婚证字号
    private String msfzjh;//男身份证号
    private String wsfzjh;//女身份证号
    private String djjgdm;//登记机关代码
    private String djjgmc;//登记机关名称
    private String mxm;//男姓名
    private String wxm;//女姓名
    private String mgj;//男国籍
    private String wgj;//女国籍
    private Date djrq;//登记日期
    private String hydjywlx;//婚姻登记业务类型
    private String proid;//项目id
    private String qlrid;//权利人id

    public String getHydjid() {
        return hydjid;
    }

    public void setHydjid(String hydjid) {
        this.hydjid = hydjid;
    }

    public String getSfzh() {
        return sfzh;
    }

    public void setSfzh(String sfzh) {
        this.sfzh = sfzh;
    }

    public String getXm() {
        return xm;
    }

    public void setXm(String xm) {
        this.xm = xm;
    }

    public Date getMcsrq() {
        return mcsrq;
    }

    public void setMcsrq(Date mcsrq) {
        this.mcsrq = mcsrq;
    }

    public Date getWcsrq() {
        return wcsrq;
    }

    public void setWcsrq(Date wcsrq) {
        this.wcsrq = wcsrq;
    }

    public String getZzh() {
        return zzh;
    }

    public void setZzh(String zzh) {
        this.zzh = zzh;
    }

    public String getMsfzjh() {
        return msfzjh;
    }

    public void setMsfzjh(String msfzjh) {
        this.msfzjh = msfzjh;
    }

    public String getWsfzjh() {
        return wsfzjh;
    }

    public void setWsfzjh(String wsfzjh) {
        this.wsfzjh = wsfzjh;
    }

    public String getDjjgdm() {
        return djjgdm;
    }

    public void setDjjgdm(String djjgdm) {
        this.djjgdm = djjgdm;
    }

    public String getDjjgmc() {
        return djjgmc;
    }

    public void setDjjgmc(String djjgmc) {
        this.djjgmc = djjgmc;
    }

    public String getMxm() {
        return mxm;
    }

    public void setMxm(String mxm) {
        this.mxm = mxm;
    }

    public String getWxm() {
        return wxm;
    }

    public void setWxm(String wxm) {
        this.wxm = wxm;
    }

    public String getMgj() {
        return mgj;
    }

    public void setMgj(String mgj) {
        this.mgj = mgj;
    }

    public String getWgj() {
        return wgj;
    }

    public void setWgj(String wgj) {
        this.wgj = wgj;
    }

    public Date getDjrq() {
        return djrq;
    }

    public void setDjrq(Date djrq) {
        this.djrq = djrq;
    }

    public String getHydjywlx() {
        return hydjywlx;
    }

    public void setHydjywlx(String hydjywlx) {
        this.hydjywlx = hydjywlx;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }
}
